########################################################################
## Vladimir Canudas-Roma
## (Translated from the Street R by carlm)
## Sample program for reading data from HMD and constructing
## graphs of cohort and period Life expectancy and Lexis surfaces
########################################################################


###Plot PERIOD Life Expectancy By Sex

## download and save to current working directory the
##    Life expectancy at birth
##    By year of death (period)
## rename it it SWE_E0per.txt
## 

A<-read.table("SWE_E0per.txt",header=TRUE,fill=TRUE,skip=2,as.is=T)



x11()
par(mfrow=c(2,1))

plot(range(A$Year),range(A$Male,A$Female),type='n',xlab='Year',
     ylab='')
title("Female, male and total period life expectancy.") 
lines(A$Year,A$Female,col='red',lty=1) 
lines(A$Year,A$Male,col='blue',lty=1)


plot(range(A$Year),range(A$Female-A$Male),type='n',xlab='Year',
     ylab='')
title("Female-Male mortality gap in the period LE.") 
lines(A$Year,(A$Female-A$Male),col='red',lty=1) 



###Plot COHORT  Life Expectancy By Sex

## Download Swedish Cohort Life Expectancy data into current directory
## and rename it SWE_E0coh.txt_

B<-read.table("SWE_E0coh.txt",header=TRUE,fill=TRUE,skip=2,as.is=T)




x11()
par(mfrow=c(2,1))

plot(range(B$Year),range(B$Male,B$Female),type='n',xlab='Year',
     ylab='')
title("Female, male and total cohort life expectancy.") 
lines(B$Year,B$Female,col='red',lty=1) 
lines(B$Year,B$Male,col='blue',lty=1)


plot(range(B$Year),range(B$Female-B$Male),type='n',xlab='Year',
     ylab='')

title("Female-Male mortality gap in the period LE.") 
lines(B$Year,(B$Female-B$Male),col='red',lty=1) 






### All on the same axes

x11()
par(mfrow=c(2,1))

plot(range(A$Year,B$Year),range(A$Male,A$Female,B$Male,B$Female),
     type='n',ylab='',xlab='Year')
title("Female, male and total period life expectancy.") 
lines(A$Year,A$Female,col='red',lty=1) 
lines(A$Year,A$Male,col='blue',lty=1)
lines(B$Year,B$Female,col='red',lty=4) 
lines(B$Year,B$Male,col='blue',lty=4)


LifeExpectancyGap<-c(min(female-male),max(female-male))
plot(Year,LifeExpectancyGap,col='white')

plot(range(A$Year,B$Year),range((A$Female-A$Male),(B$Female-B$Male)),
     type='n',ylab='',xlab='Year')

title("Female-male mortality gap in the period and cohort LE.") 
lines(A$Year,(A$Female-A$Male),col='red',lty=1) 
lines(B$Year,(B$Female-B$Male),col='blue',lty=1) 


########################################################################
## Now read death rates for lexis surfaces
##  Dowload Single Year period death rates
##  make sure it is in the directory that you launched R from
##  name the file "SWE_Mx_1x1.txt"
########################################################################


CC<-read.table("SWE_Mx_1x1.txt",skip=2,as.is=T,header=TRUE,na.strings='.')
CC$Age[CC$Age =="110+"] <- 110
CC$Age<-as.numeric(CC$Age)


#############################################
## create a matrix of male Mx where rows indicate year
## and column indicate age
#############################################
MaleMx<-with(CC,
             tapply(Male,list(Year,Age),sum)
             )



contour(MaleMx,xlab="",ylab="",levels=c(.0001,.001,.005,.01,.05))




x11()
library(lattice)
contourplot( Male~ Year+Age,data=CC,at=c(.0001,.0005,.001,.005,.01,.05))

### add color between regions
contourplot( Male~ Year+Age,data=CC,at=c(.0001,.0005,.001,.005,.01,.05),
            region=T)

### Or start with the colored regions and skip the lines
levelplot( Male~ Year+Age,data=CC,
          main=("Lexis Surface for Swedish deaths rates"))
levelplot( log(Male)~ Year+Age,data=CC,
                    main=("Lexis Surface for Swedish deaths rates"))
levelplot( Male~ Year+Age,data=CC,
          at=c(0,.00001,.0001,.0005,.001,.005,.01,.05,.1,1),
          col.regions=rainbow(n=100),
          main=("Lexis Surface for Swedish deaths rates"))

#### Let's put males and females together on one page
Fem<-CC[,1:3]
Fem$Sex="Female"
Mal<-CC[,c(1,2,4)]
Mal$Sex="Male"
names(Mal)<-names(Fem)<-c("Year","Age","Mx","Sex")
CC2<-rbind(Fem,Mal)

levelplot( Mx~ Year+Age|Sex,data=CC2,
          at=c(.00001,.0001,.0005,.001,.005,.01,.05,.1),
          col.regions=topo.colors(n=20),
          main=("Lexis Surface for Swedish deaths rates"))




